Quick reference for keyboard shortcuts in Mimir.
| Shortcut | Action |
Escape | Close modal/panel |
| Shortcut | Action |
Scroll | Zoom in/out |
Click + Drag | Pan the map |
+ / = | Zoom in |
- | Zoom out |
0 | Reset view (1:1 zoom, centered) |
| Shortcut | Action |
Click | Select token |
Drag | Move token |
Right-click | Token context menu |
h / H | Toggle visibility of selected token |
d / D | Toggle dead state of selected token |
Escape | Close context menu and deselect token |
| Shortcut | Action |
F11 | Toggle fullscreen |
R | Reset view (fit map to screen) |
| Shortcut | Action |
Cmd/Ctrl + B | Bold |
Cmd/Ctrl + I | Italic |
Cmd/Ctrl + Z | Undo |
Cmd/Ctrl + Shift + Z | Redo |
Cmd is used on macOS, Ctrl on Windows/Linux
- Shortcuts are ignored when typing in text inputs or textareas
- Token manipulation shortcuts require a token to be selected